"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.createTransformer = undefined;

var _bluebirdLst;

function _load_bluebirdLst() {
    return _bluebirdLst = require("bluebird-lst");
}

let createTransformer = exports.createTransformer = (() => {
    var _ref = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (projectDir, srcDir, packager) {
        const extraMetadata = packager.packagerOptions.extraMetadata;
        const mainPackageJson = _path.join(srcDir, "package.json");
        const defaultTransformer = function (file) {
            if (file === mainPackageJson) {
                return modifyMainPackageJson(file, extraMetadata);
            } else if (file.endsWith("/package.json") && file.indexOf("/node_modules/") !== -1) {
                return (0, (_fsExtraP || _load_fsExtraP()).readJson)(file).then(function (it) {
                    return cleanupPackageJson(it);
                }).catch(function (e) {
                    return (0, (_log || _load_log()).warn)(e);
                });
            } else {
                return null;
            }
        };
        return isElectronCompileUsed(packager.info) ? yield createElectronCompileTransformer(projectDir, defaultTransformer) : defaultTransformer;
    });

    return function createTransformer(_x, _x2, _x3) {
        return _ref.apply(this, arguments);
    };
})();

let createElectronCompileTransformer = (() => {
    var _ref2 = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (projectDir, defaultTransformer) {
        const electronCompilePath = _path.join(projectDir, "node_modules", "electron-compile", "lib");
        const CompilerHost = require(_path.join(electronCompilePath, "compiler-host")).default;
        const compilerHost = yield require(_path.join(electronCompilePath, "config-parser")).createCompilerHostFromProjectRoot(projectDir);
        return (() => {
            var _ref3 = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (file) {
                const defaultResult = defaultTransformer(file);
                if (defaultResult != null) {
                    return yield defaultResult;
                }
                if (file.indexOf("/node_modules/") !== -1 || file.indexOf("/bower_components/") !== -1) {
                    return null;
                }
                const hashInfo = yield compilerHost.fileChangeCache.getHashForPath(file);
                if (CompilerHost.shouldPassthrough(hashInfo)) {
                    return null;
                }
                // we don't use @paulcbetts/mime-types to lookup mime-type because it doesn't any value except size (@develar 20.03.17)
                // as we already depends on mime module (github publisher)
                // https://github.com/electron/electron-compile/pull/148#issuecomment-266669293
                const type = (_mime || _load_mime()).default.lookup(file);
                const compiler = type == null ? null : compilerHost.compilersByMimeType[type];
                if (compiler == null) {
                    return null;
                }
                const cache = compilerHost.cachesForCompilers.get(compiler);
                const result = yield cache.getOrFetch(file, function (file, hashInfo) {
                    return compilerHost.compileUncached(file, hashInfo, compiler);
                });
                return result.code || result.binaryData;
            });

            return function (_x6) {
                return _ref3.apply(this, arguments);
            };
        })();
    });

    return function createElectronCompileTransformer(_x4, _x5) {
        return _ref2.apply(this, arguments);
    };
})();

let modifyMainPackageJson = (() => {
    var _ref4 = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (file, extraMetadata) {
        const mainPackageData = yield (0, (_fsExtraP || _load_fsExtraP()).readJson)(file);
        if (extraMetadata != null) {
            (0, (_deepAssign || _load_deepAssign()).deepAssign)(mainPackageData, extraMetadata);
        }
        // https://github.com/electron-userland/electron-builder/issues/1212
        const serializedDataIfChanged = cleanupPackageJson(mainPackageData);
        if (serializedDataIfChanged != null) {
            return serializedDataIfChanged;
        } else if (extraMetadata != null) {
            return JSON.stringify(mainPackageData, null, 2);
        }
        return null;
    });

    return function modifyMainPackageJson(_x7, _x8) {
        return _ref4.apply(this, arguments);
    };
})();
//# sourceMappingURL=fileTransformer.js.map


var _electronBuilderUtil;

function _load_electronBuilderUtil() {
    return _electronBuilderUtil = require("electron-builder-util");
}

var _deepAssign;

function _load_deepAssign() {
    return _deepAssign = require("electron-builder-util/out/deepAssign");
}

var _log;

function _load_log() {
    return _log = require("electron-builder-util/out/log");
}

var _fsExtraP;

function _load_fsExtraP() {
    return _fsExtraP = require("fs-extra-p");
}

var _mime;

function _load_mime() {
    return _mime = _interopRequireDefault(require("mime"));
}

var _path = _interopRequireWildcard(require("path"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function isElectronCompileUsed(info) {
    const depList = [info.metadata.devDependencies, info.metadata.dependencies];
    if (info.isTwoPackageJsonProjectLayoutUsed) {
        depList.push(info.devMetadata.devDependencies);
        depList.push(info.devMetadata.dependencies);
    }
    for (const deps of depList) {
        if (deps != null && "electron-compile" in deps) {
            (0, (_log || _load_log()).log)("electron-compile detected — files will be compiled");
            return true;
        }
    }
    return false;
}

function cleanupPackageJson(data) {
    try {
        let changed = false;
        for (const prop of Object.getOwnPropertyNames(data)) {
            if (prop[0] === "_" || prop === "dist" || prop === "gitHead" || prop === "keywords" || prop === "build" || prop === "devDependencies" || prop === "scripts") {
                delete data[prop];
                changed = true;
            }
        }
        if (changed) {
            return JSON.stringify(data, null, 2);
        }
    } catch (e) {
        (0, (_electronBuilderUtil || _load_electronBuilderUtil()).debug)(e);
    }
    return null;
}